@@ -244,20 +244,31 @@ class OrderSerializer(serializers.ModelSerializer):
         if "payment_method" in attrs:
             payment_method = attrs["payment_method"]
             if payment_method.payment_provider == tby_settings.WALLET:
-                # TODO: after we make each wallet to currency we should change this
+                try:
+                    wallet = user.wallets.get(country=attrs["store"].address.country)
+                except ObjectDoesNotExist:
+                    raise serializers.ValidationError(
+                        {
+                            "wallet": _(
+                                "The currency of our store is not compatible with your wallet. Please checkout with products using different currency"
+                            )
+                        }
+                    )
                 if "extra_infos" in attrs:
                     amount = attrs["extra_infos"]["price"]
                 else:
                     amount = user.cart.total_price
-                if user.wallet.balance < amount:
+                if wallet.balance < amount:
                     raise serializers.ValidationError(
                         {"wallet": _("Insufficient Funds")},
                     )
+
         return super().validate(attrs)
 
     def create(self, validated_data: typing.Dict):
         user = self.context["request"].user
         orders = []
+        order_store = validated_data["store"]
         if "extra_infos" in validated_data:
             amount = validated_data["extra_infos"]["price"]
             variant = ProductVariant.objects.get(
@@ -293,7 +304,7 @@ class OrderSerializer(serializers.ModelSerializer):
             user=user,
             amount=amount,
             method=validated_data.get("payment_method"),
-            currency=settings.DEFAULT_CURRENCY,
+            currency=order_store.currency,
             orders=orders,
         )
         return {
@@ -677,7 +688,7 @@ class StoreSerializer(serializers.ModelSerializer):
     def get_is_closed(self, obj):
         current_time = now()
         current_op_hour = obj.opening_hours.filter(
-            weekday=current_time.weekday()
+            weekday=current_time.weekday() + 1
         ).first()
         if current_op_hour:
             return (
