@@ -14,14 +14,13 @@ class TapPaymentManager(models.Manager):
             "source" not in kwargs
             or kwargs.get("source") not in self.model.Sources.values
         ):
-            raise ValueError("Invalid source value.")
+            raise ValueError(f"Invalid source value. {kwargs.get('source')}")
         source = kwargs.pop("source")
         payment = kwargs.get("payment")
         user = kwargs.get("user")
         tap_response = utils.initiate_payment(
             source,
             user,
-            payment.order,
             payment,
             payment.currency,
         )
