@@ -6,6 +6,7 @@ from django.db import models
 from django.utils.translation import gettext_lazy as _
 
 from config import settings
+from ob_dj_store.core.stores.utils import get_country_by_currency
 
 
 class ActiveMixin:
@@ -70,8 +71,13 @@ class PaymentManager(models.Manager):
                 user=kwargs.get("user"),
             )
         elif gateway == settings.WALLET:
+            try:
+                country = get_country_by_currency(kwargs["currency"])
+                wallet = kwargs["user"].wallets.get(country=country)
+            except ObjectDoesNotExist:
+                raise ValidationError({"wallet": _("Wallet Not Found")})
             WalletTransaction.objects.create(
-                wallet=kwargs["user"].wallet,
+                wallet=wallet,
                 type=WalletTransaction.TYPE.DEBIT,
                 amount=kwargs["amount"],
             )
