@@ -1,7 +1,7 @@
 from decimal import Decimal
 
 from django.contrib.auth import get_user_model
-from django.core.exceptions import ObjectDoesNotExist
+from django.core.exceptions import ObjectDoesNotExist, ValidationError
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
@@ -15,7 +15,6 @@ class Cart(models.Model):
         related_name="cart",
         primary_key=True,
     )
-
     # Audit fields
     created_at = models.DateTimeField(auto_now_add=True)
     updated_at = models.DateTimeField(auto_now=True)
@@ -26,6 +25,22 @@ class Cart(models.Model):
         verbose_name_plural = _("Carts")
         verbose_name = _("Cart")
 
+    @property
+    def tax_amount(self) -> Decimal:
+        from ob_dj_store.core.stores.models import Tax
+
+        try:
+            tax = Tax.objects.get(is_active=True)
+        except ObjectDoesNotExist:
+            raise ValidationError(_("Tax object is missing"), code="invalid")
+
+        if not tax:
+            return 0
+        if tax.rate == Tax.Rates.PERCENTAGE:
+            perc = Decimal(self.total_price * tax.value / 100)
+            return perc
+        return tax.value
+
     @property
     def total_price(self) -> Decimal:
         total_price = Decimal(0)
@@ -33,6 +48,10 @@ class Cart(models.Model):
             total_price += item.total_price
         return total_price
 
+    @property
+    def total_price_with_tax(self) -> Decimal:
+        return self.total_price + self.tax_amount
+
     def __str__(self):
         return f"Cart - {self.customer.email} with total price {self.total_price}"
 
@@ -44,7 +63,11 @@ class CartItem(models.Model):
     )
     quantity = models.PositiveIntegerField(default=1)
     store = models.ForeignKey(
-        "stores.Store", on_delete=models.CASCADE, related_name="store_items"
+        "stores.Store",
+        on_delete=models.CASCADE,
+        related_name="store_items",
+        null=True,
+        blank=True,
     )
     # notes for special instructions, can be empty
     notes = models.TextField(blank=True, null=True, help_text=_("Special instructions"))
@@ -55,6 +78,7 @@ class CartItem(models.Model):
         related_name="cart_items",
         help_text=_("Attribute choices for the item"),
     )
+    extra_infos = models.JSONField(null=True, blank=True)
     # Audit fields
     created_at = models.DateTimeField(auto_now_add=True)
     updated_at = models.DateTimeField(auto_now=True)
@@ -74,6 +98,13 @@ class CartItem(models.Model):
         except ObjectDoesNotExist:
             return 0
 
+    @property
+    def attribute_choices_total_price(self) -> Decimal:
+        total_price = Decimal(0)
+        for attribute_choice in self.attribute_choices.all():
+            total_price += attribute_choice.price
+        return total_price
+
     @property
     def inventory(self) -> Decimal:
         try:
@@ -81,9 +112,14 @@ class CartItem(models.Model):
         except ObjectDoesNotExist:
             return None
 
+    def clean(self):
+        super(CartItem, self).clean()
+        if self.product_variant.product.type == "PHYSICAL" and not self.store:
+            raise ValidationError(_("The store attribute can not be null"))
+
     @property
     def total_price(self) -> Decimal:
-        return self.unit_price * self.quantity
+        return (self.unit_price + self.attribute_choices_total_price) * self.quantity
 
     def __str__(self):
         return f"CartItem - {self.quantity} {self.product_variant.name}"
